package cn.teammodel.controller.admin.controller;

import cn.teammodel.common.R;
import cn.teammodel.controller.admin.service.TeacherService;
import cn.teammodel.model.dto.admin.exam.ExamRecordDto;
import cn.teammodel.model.dto.admin.exam.OverViewDto;
import cn.teammodel.model.dto.admin.teacher.TeacherDto;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.validation.Valid;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("admin/teacher")
@Api(tags = "教师相关接口内容")
public class TeacherController {
    @Resource
    private TeacherService teacherService;
    @PostMapping("getCount")
    @ApiOperation("获取教师基础数据统计内容")
    public R<List<Map<String, Integer>>> getCount(@Valid @RequestBody TeacherDto teacherDto) {
        List<Map<String, Integer>> res = teacherService.getTeacherList(teacherDto);
        return R.success(res);
    }
    @PostMapping("getTeacherDetail")
    @ApiOperation("获取教师详细数据")
    public R<Map<String, Object>> getTeacherDetail(@Valid @RequestBody TeacherDto teacherDto, HttpServletRequest request) {
        Map<String, Object> res = teacherService.getTeacherDetail(teacherDto,request);
        return R.success(res);
    }
    @PostMapping("getTeacherCountRecordOfWeek")
    @ApiOperation("获取当前学期指定教师每周课程数")
    public R<Map<Long, Integer>> getTeacherCountRecordOfWeek(@Valid @RequestBody TeacherDto teacherDto) {
        Map<Long, Integer> res = teacherService.getTeacherByRecord(teacherDto);
        return R.success(res);
    }
    @PostMapping("getTeacherLearningCategoryCount")
    @ApiOperation("获取指定教师教学法统计")
    public R<Map<String, Object>> getTeacherLearningCategoryCount(@Valid @RequestBody TeacherDto teacherDto) {
        Map<String, Object> res = teacherService.getTeacherLearningCategory(teacherDto);
        return R.success(res);
    }
    @PostMapping("getTeacherGradeCount")
    @ApiOperation("获取年级人数以及分配情况")
    public R<Map<String, Object>> getTeacherGradeCount(@Valid @RequestBody TeacherDto teacherDto, HttpServletRequest request) {
        Map<String, Object> res = teacherService.getTeacherGradeCount(teacherDto,request);
        return R.success(res);
    }
    @PostMapping("getDistributionOfTeachers")
    @ApiOperation("获取教师分布情况")
    public R<List<Map<String,Map<String, Long>>>> getDistributionOfTeachers(@Valid @RequestBody TeacherDto teacherDto, HttpServletRequest request) {
        List<Map<String,Map<String, Long>>> res = teacherService.getDistributionOfTeachers(teacherDto,request);
        return R.success(res);
    }

    @PostMapping("getTeachingAndResearch")
    @ApiOperation("获取教师教研数据")
    public R<Map<String,Object>> getTeachingAndResearch(@Valid @RequestBody TeacherDto teacherDto, HttpServletRequest request) {
        Map<String,Object> res = teacherService.getTeachingAndResearch(teacherDto,request);
        return R.success(res);
    }
    @PostMapping("getTeachingOfTeacher")
    @ApiOperation("获取教师教学法数据")
    public R<List<LinkedHashMap<String, LinkedHashMap<String,Object>>> > getTeachingOfTeacher(@Valid @RequestBody TeacherDto teacherDto, HttpServletRequest request) {
        List<LinkedHashMap<String,LinkedHashMap<String,Object>>>  res = teacherService.getTeachingOfTeacher(teacherDto,request);
        return R.success(res);
    }


}
